/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui;

import static org.fortiss.tooling.kernel.ui.internal.ToolingKernelUIInternal.initializeKernelUI;
import static org.fortiss.tooling.kernel.ui.internal.ToolingKernelUIInternal.startKernelUI;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.model.constraints.IConstraint;
import org.fortiss.tooling.kernel.ui.extension.IAllocationEditPartFactory;
import org.fortiss.tooling.kernel.ui.extension.IConstraintVerifierUI;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.extension.IEditPartFactory;
import org.fortiss.tooling.kernel.ui.extension.IModelEditorBinding;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.internal.ToolingKernelUIInternal;

/**
 * Class for initializing and starting the user interface part of the tooling kernel.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public final class ToolingKernelUI {
	/** Initializes the UI services. */
	public static void initialize() {
		initializeKernelUI();
	}

	/** Starts the UI services. */
	public static void start() {
		startKernelUI();
	}

	/** Registers the given allocation editpart factory with the kernel. */
	public static void registerAllocationEditpartFactory(IAllocationEditPartFactory factory,
			Class<EObject> modelElementClass) {
		ToolingKernelUIInternal.registerAllocationEditpartFactory(factory, modelElementClass);
	}

	/** Registers the verifier UI part with the kernel. */
	public static <T extends IConstraint> void registerConstraintVerifierUI(
			IConstraintVerifierUI<T> verifier, Class<T> constraintElementClass) {
		ToolingKernelUIInternal.registerConstraintVerifierUI(verifier, constraintElementClass);
	}

	/** Registers the given contributor with the kernel. */
	public static void registerContextMenuContributor(IContextMenuContributor contributor) {
		ToolingKernelUIInternal.registerContextMenuContributor(contributor);
	}

	/** Registers the given editpart factory with the kernel. */
	public static void registerEditpartFactory(IEditPartFactory factory,
			Class<EObject> modelElementClass) {
		ToolingKernelUIInternal.registerEditpartFactory(factory, modelElementClass);
	}

	/** Registers the given editor binding with the kernel. */
	public static <T extends EObject> void registerEditorBinding(IModelEditorBinding<T> binding,
			Class<T> modelElementClass) {
		ToolingKernelUIInternal.registerEditorBinding(binding, modelElementClass);
	}

	/** Registers the given handler with the kernel. */
	public static <T extends EObject> void registerModelElementHandler(
			IModelElementHandler<T> handler, Class<T> modelElementClass) {
		ToolingKernelUIInternal.registerModelElementHandler(handler, modelElementClass);
	}
}
